# mlopx

Status: **In Development**

Python package that allows the development of intuitive ML pipelines which are internally converted to Kubeflow pipelines.
This package focus on optimizing the deployment of ML pipelines in heterogeneous kubernetes clusters.
This package is intended to be used along with the mlopx server.